﻿using Bing.Maps;
using System;
using Windows.UI.Xaml.Controls;

namespace BingMapsIntro_WinRT_CS
{
    public sealed partial class GpsIcon : UserControl
    {
        private Map _map;
        private double _radius;
        private const double EARTH_RADIUS_METERS = 6378137;

        public GpsIcon(Map map)
        {
            this.InitializeComponent();

            _map = map;

            //Add a View Changed event to the map to update the accuracy circle
            _map.ViewChanged += (s, e) =>
            {
                //Update the accuracy circle
                UpdateAccuracyCircle();
            };
        }

        public void SetRadius(double radiusInMeters)
        {
            //Store the radius value
            _radius = radiusInMeters;

            //Update the accuracy circle
            UpdateAccuracyCircle();
        }

        private void UpdateAccuracyCircle()
        {
            if (_map != null && _radius >= 0)
            {
                //Calculate the ground resolution in meters/pixel
                //Math based on http://msdn.microsoft.com/en-us/library/bb259689.aspx
                double groundResolution = Math.Cos(_map.Center.Latitude * Math.PI / 180) * 
                    2 * Math.PI * EARTH_RADIUS_METERS / (256 * Math.Pow(2, _map.ZoomLevel));

                //Calculate the radius of the accuracy circle in pixels
                double pixelRadius = _radius / groundResolution;

                //Update the accuracy circle dimensions
                AccuracyCircle.Width = pixelRadius;
                AccuracyCircle.Height = pixelRadius;

                //Use the margin property to center the accuracy circle
                AccuracyCircle.Margin = new Windows.UI.Xaml.Thickness(-pixelRadius/2, -pixelRadius/2, 0, 0);
            }
        }
    }
}
